@@ -492,6 +492,53 @@ class FleetManagementServiceAsyncClient:
         # Done; return the response.
         return response
 
+    async def list_vessels_with_status(self,
+            request: service.ListVesselsWithStatusRequest = None,
+            *,
+            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            timeout: float = None,
+            metadata: Sequence[Tuple[str, str]] = (),
+            ) -> service.Vessels:
+        r"""Retrieves list of vessels in a Fleet.
+
+        Args:
+            request (:class:`oceanbolt.com.fleetmanagement_v3.types.ListVesselsWithStatusRequest`):
+                The request object. Request object for listing Fleet
+                Vessels with status (live state) data and speed events
+
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            oceanbolt.com.fleetmanagement_v3.types.Vessels:
+                List of Vessel objects
+        """
+        # Create or coerce a protobuf request object.
+
+        request = service.ListVesselsWithStatusRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.list_vessels_with_status,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
     async def add_vessel(self,
             request: service.AddVesselRequest = None,
             *,
