@@ -692,6 +692,54 @@ class FleetManagementServiceClient(metaclass=FleetManagementServiceClientMeta):
         # Done; return the response.
         return response
 
+    def list_vessels_with_status(self,
+            request: service.ListVesselsWithStatusRequest = None,
+            *,
+            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            timeout: float = None,
+            metadata: Sequence[Tuple[str, str]] = (),
+            ) -> service.Vessels:
+        r"""Retrieves list of vessels in a Fleet.
+
+        Args:
+            request (oceanbolt.com.fleetmanagement_v3.types.ListVesselsWithStatusRequest):
+                The request object. Request object for listing Fleet
+                Vessels with status (live state) data and speed events
+
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            oceanbolt.com.fleetmanagement_v3.types.Vessels:
+                List of Vessel objects
+        """
+        # Create or coerce a protobuf request object.
+
+        # Minor optimization to avoid making a copy if the user passes
+        # in a service.ListVesselsWithStatusRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, service.ListVesselsWithStatusRequest):
+            request = service.ListVesselsWithStatusRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[self._transport.list_vessels_with_status]
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
     def add_vessel(self,
             request: service.AddVesselRequest = None,
             *,
